@@ -3,11 +3,14 @@
 
 #include "config.h"
 #include "AsyncUserInput.hxx"
+#include "UserInputHandler.hxx"
 #include "Command.hxx"
 #include "Bindings.hxx"
 #include "GlobalBindings.hxx"
-#include "ncmpc.hxx"
-#include "Point.hxx"
+#include "ui/Point.hxx"
+
+// TODO remove this kludge
+static AsyncUserInput *global_async_user_input;
 
 static constexpr bool
 ignore_key(int key) noexcept
@@ -31,6 +34,13 @@ AsyncUserInput::OnSocketReady(unsigned) noexcept
 
 #ifdef HAVE_GETMOUSE
 	if (key == KEY_MOUSE) {
+		if (handler.CancelModalDialog()) {
+			/* cancel the modal dialog on mouse click;
+			   though some day, we may allow modal dialogs
+			   to handle mouse events */
+			return;
+		}
+
 		MEVENT event;
 
 		/* retrieve the mouse event from curses */
@@ -40,42 +50,44 @@ AsyncUserInput::OnSocketReady(unsigned) noexcept
 		getmouse(&event);
 #endif
 
-		begin_input_event();
-		do_mouse_event({event.x, event.y}, event.bstate);
-		end_input_event();
-
+		handler.OnMouse({event.x, event.y}, event.bstate);
 		return;
 	}
 #endif
 
-	Command cmd = translate_key(key);
-	if (cmd == Command::NONE)
+	if (handler.OnRawKey(key)) {
 		return;
+	}
 
-	begin_input_event();
-
-	if (!do_input_event(stdin_event.GetEventLoop(), cmd))
-		return;
-
-	end_input_event();
-	return;
+	if (Command cmd = translate_key(key); cmd != Command::NONE)
+		handler.OnCommand(cmd);
 }
 
-AsyncUserInput::AsyncUserInput(EventLoop &event_loop, WINDOW &_w) noexcept
+AsyncUserInput::AsyncUserInput(EventLoop &event_loop, WINDOW &_w,
+			       UserInputHandler &_handler) noexcept
 	:stdin_event(event_loop, BIND_THIS_METHOD(OnSocketReady),
 		      FileDescriptor{STDIN_FILENO}),
-	 w(_w)
+	 w(_w),
+	 handler(_handler)
 {
 	stdin_event.ScheduleRead();
+
+	// TODO remove this kludge
+	global_async_user_input = this;
 }
 
-void
-keyboard_unread(EventLoop &event_loop, int key) noexcept
+inline void
+AsyncUserInput::InjectKey(int key) noexcept
 {
 	if (ignore_key(key))
 		return;
 
-	Command cmd = translate_key(key);
-	if (cmd != Command::NONE)
-		do_input_event(event_loop, cmd);
+	if (Command cmd = translate_key(key); cmd != Command::NONE)
+		handler.OnCommand(cmd);
+}
+
+void
+keyboard_unread(int key) noexcept
+{
+	global_async_user_input->InjectKey(key);
 }
