@@ -1,26 +1,11 @@
-/* ncmpc (Ncurses MPD Client)
- * Copyright 2004-2021 The Music Player Daemon Project
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- */
+// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright The Music Player Daemon Project
 
 #include "BasicColors.hxx"
+#include "util/StringAPI.hxx"
 
 #include <curses.h>
 
-#include <strings.h>
 #include <stdlib.h>
 
 static constexpr const char *basic_color_names[] = {
@@ -48,7 +33,7 @@ short
 ParseBasicColorName(const char *name) noexcept
 {
 	for (size_t i = 0; basic_color_names[i] != nullptr; ++i)
-		if (strcasecmp(basic_color_names[i], name) == 0)
+		if (StringIsEqualIgnoreCase(basic_color_names[i], name))
 			return i;
 
 	return -1;
