@@ -4,25 +4,22 @@
 #include "BasicMarquee.hxx"
 #include "util/LocaleString.hxx"
 
+#include <fmt/core.h>
+
 #include <assert.h>
 #include <string.h>
 
-std::pair<const char *, size_t>
+using std::string_view_literals::operator""sv;
+
+std::string_view
 BasicMarquee::ScrollString() const noexcept
 {
-	assert(separator != nullptr);
-
-	const char *p = AtCharMB(buffer.data(), buffer.length(), offset);
-	const char *end = AtWidthMB(p, strlen(p), width);
-	return std::make_pair(p, size_t(end - p));
+	return TruncateAtWidthMB(SplitAtCharMB(buffer, offset).second, width);
 }
 
 bool
-BasicMarquee::Set(unsigned _width, const char *_text) noexcept
+BasicMarquee::Set(unsigned _width, std::string_view _text) noexcept
 {
-	assert(separator != nullptr);
-	assert(_text != nullptr);
-
 	if (_width == width && text == _text)
 		/* no change, do nothing (and, most importantly, do
 		   not reset the current offset!) */
@@ -34,8 +31,8 @@ BasicMarquee::Set(unsigned _width, const char *_text) noexcept
 	text = _text;
 
 	/* create a buffer containing the string and the separator */
-	buffer = text + separator + text + separator;
-	max_offset = StringLengthMB(buffer.data(), buffer.length() / 2);
+	buffer = fmt::format("{}{}{}{}"sv, text, separator, text, separator);
+	max_offset = StringLengthMB(buffer.substr(buffer.size() / 2));
 
 	return true;
 }
