@@ -4,7 +4,6 @@
 #include "FileBrowserPage.hxx"
 #include "PageMeta.hxx"
 #include "FileListPage.hxx"
-#include "screen_status.hxx"
 #include "save_playlist.hxx"
 #include "screen.hxx"
 #include "config.h" // IWYU pragma: keep
@@ -238,10 +237,9 @@ FileBrowserPage::HandleDelete(struct mpdclient &c)
 		}
 
 		const auto *playlist = mpd_entity_get_playlist(entity);
-		char prompt[256];
-		snprintf(prompt, sizeof(prompt),
-			 _("Delete playlist %s?"),
-			 Utf8ToLocaleZ{GetUriFilename(mpd_playlist_get_path(playlist))}.c_str());
+
+		const auto prompt = fmt::format(fmt::runtime(_("Delete playlist {}?")),
+						(std::string_view)Utf8ToLocale{GetUriFilename(mpd_playlist_get_path(playlist))});
 
 		if (co_await YesNoDialog{screen, prompt} != YesNoResult::YES)
 			co_return;
@@ -345,7 +343,7 @@ FileBrowserPage::OnCommand(struct mpdclient &c, Command cmd)
 		break;
 
 	case Command::DB_UPDATE:
-		screen_database_update(c, current_path.c_str());
+		screen_database_update(GetInterface(), c, current_path.c_str());
 		return true;
 
 	default:
