@@ -6,12 +6,14 @@
 #include "PageMeta.hxx"
 #include "FileListPage.hxx"
 #include "Command.hxx"
-#include "ProxyPage.hxx"
 #include "i18n.h"
 #include "charset.hxx"
-#include "mpdclient.hxx"
 #include "filelist.hxx"
 #include "Options.hxx"
+#include "screen.hxx"
+#include "page/ProxyPage.hxx"
+#include "lib/fmt/ToSpan.hxx"
+#include "client/mpdclient.hxx"
 
 #include <list>
 #include <string>
@@ -20,6 +22,8 @@
 #include <assert.h>
 #include <string.h>
 
+using std::string_view_literals::operator""sv;
+
 [[gnu::const]]
 static const char *
 GetTagPlural(enum mpd_tag_type tag) noexcept
@@ -36,16 +40,15 @@ GetTagPlural(enum mpd_tag_type tag) noexcept
 	}
 }
 
-static const char *
-MakePageTitle(char *buffer, size_t size, const char *prefix,
+static std::string_view 
+MakePageTitle(std::span<char> buffer, std::string_view prefix,
 	      const TagFilter &filter)
 {
 	if (filter.empty())
 		return prefix;
 
-	snprintf(buffer, size, "%s: %s", prefix,
-		 Utf8ToLocale(ToString(filter).c_str()).c_str());
-	return buffer;
+	return FmtTruncate(buffer, "{}: {}"sv, prefix,
+			   (std::string_view)Utf8ToLocale{ToString(filter)});
 }
 
 class SongListPage final : public FileListPage {
@@ -54,9 +57,9 @@ class SongListPage final : public FileListPage {
 	TagFilter filter;
 
 public:
-	SongListPage(ScreenManager &_screen, Page *_parent,
-		     WINDOW *_w, Size size) noexcept
-		:FileListPage(_screen, _w, size,
+	SongListPage(PageContainer &_container, ScreenManager &_screen, Page *_parent,
+		     const Window _window) noexcept
+		:FileListPage(_container, _screen, _window,
 			      options.list_format.c_str()),
 		 parent(_parent) {}
 
@@ -80,7 +83,7 @@ public:
 	/* virtual methods from class Page */
 	void Update(struct mpdclient &c, unsigned events) noexcept override;
 	bool OnCommand(struct mpdclient &c, Command cmd) override;
-	const char *GetTitle(char *s, size_t size) const noexcept override;
+	std::string_view GetTitle(std::span<char> buffer) const noexcept override;
 };
 
 void
@@ -97,13 +100,13 @@ class LibraryTagListPage final : public TagListPage {
 	ArtistBrowserPage &library_page;
 
 public:
-	LibraryTagListPage(ScreenManager &_screen,
+	LibraryTagListPage(PageContainer &_container, ScreenManager &_screen,
 			   ArtistBrowserPage &_library_page,
 			   Page *_parent,
 			   const enum mpd_tag_type _tag,
 			   const char *_all_text,
-			   WINDOW *_w, Size size) noexcept
-		:TagListPage(_screen, _parent, _tag, _all_text, _w, size),
+			   const Window _window) noexcept
+		:TagListPage(_container, _screen.find_support, _parent, _tag, _all_text, _window),
 		 library_page(_library_page) {}
 
 protected:
@@ -117,19 +120,18 @@ class ArtistBrowserPage final : public ProxyPage {
 	SongListPage song_list_page;
 
 public:
-	ArtistBrowserPage(ScreenManager &_screen, WINDOW *_w,
-			  Size size)
-		:ProxyPage(_w),
-		 song_list_page(_screen, this,
-				_w, size) {
+	ArtistBrowserPage(ScreenManager &_screen, const Window _window)
+		:ProxyPage(_screen, _window),
+		 song_list_page(*this, _screen, this,
+				_window) {
 
 		bool first = true;
 		for (const auto &tag : options.library_page_tags) {
-			tag_list_pages.emplace_back(_screen, *this,
+			tag_list_pages.emplace_back(*this, _screen, *this,
 						    first ? nullptr : this,
 						    tag,
 						    first ? nullptr : _("All"),
-						    _w, size);
+						    _window);
 			first = false;
 		}
 	}
@@ -181,7 +183,7 @@ ArtistBrowserPage::OpenTagPage(struct mpdclient &c,
 	page->SetFilter(std::move(filter));
 
 	char buffer[64];
-	page->SetTitle(MakePageTitle(buffer, sizeof(buffer),
+	page->SetTitle(MakePageTitle(buffer,
 				     _("Albums"),
 				     page->GetFilter()));
 
@@ -196,15 +198,15 @@ ArtistBrowserPage::OpenSongList(struct mpdclient &c, TagFilter &&filter)
 }
 
 static std::unique_ptr<Page>
-InitLibraryPage(ScreenManager &_screen, WINDOW *w, Size size)
+InitLibraryPage(ScreenManager &_screen, const Window window)
 {
-	return std::make_unique<ArtistBrowserPage>(_screen, w, size);
+	return std::make_unique<ArtistBrowserPage>(_screen, window);
 }
 
-const char *
-SongListPage::GetTitle(char *str, size_t size) const noexcept
+std::string_view
+SongListPage::GetTitle(std::span<char> buffer) const noexcept
 {
-	return MakePageTitle(str, size, _("Songs"), filter);
+	return MakePageTitle(buffer, _("Songs"), filter);
 }
 
 bool
