@@ -130,6 +130,32 @@ FormatStatusRightText(std::span<char> buffer,
 	return {buffer.data(), bitrate_string.size() + time_string.size()};
 }
 
+void
+StatusBar::UpdateScrollLayout() noexcept
+{
+#ifndef NCMPC_MINI
+	if (!options.scroll)
+		return;
+
+	const unsigned window_width = window.GetWidth();
+	if (left_width + right_width >= window_width)
+		/* there's no room for the center_text */
+		return;
+
+	const unsigned remaining_width = window_width - (left_width + right_width);
+
+	const unsigned center_width =
+		StringWidthMB(center_text);
+	if (window_width > 3 && center_width > remaining_width) {
+		hscroll.Set({(int)left_width, 0}, remaining_width,
+			    center_text,
+			    Style::STATUS);
+	} else {
+		hscroll.Clear();
+	}
+#endif
+}
+
 void
 StatusBar::Update(const struct mpd_status *status,
 		  const struct mpd_song *song,
@@ -171,20 +197,7 @@ StatusBar::Update(const struct mpd_status *status,
 			center_text.clear();
 
 		/* scroll if the song name is to long */
-#ifndef NCMPC_MINI
-		if (options.scroll) {
-			const unsigned window_width = window.GetWidth();
-			const unsigned center_width =
-				StringWidthMB(center_text);
-			if (window_width > 3 && center_width > window_width) {
-				hscroll.Set({(int)left_width, 0}, window_width,
-					    center_text,
-					    Style::STATUS);
-			} else {
-				hscroll.Clear();
-			}
-		}
-#endif
+		UpdateScrollLayout();
 	} else {
 		right_width = 0;
 		center_text.clear();
@@ -225,7 +238,7 @@ StatusBar::Paint() const noexcept
 		window.String({x, 0}, {right_buffer, right_length});
 	}
 
-	if (!center_text.empty()) {
+	if (!center_text.empty() && left_width + right_length < window_width) {
 		/* display song name */
 
 		SelectStyle(window, Style::STATUS);
@@ -247,6 +260,8 @@ StatusBar::OnResize(Point p, unsigned width) noexcept
 {
 	window.Resize({width, 1u});
 	window.Move(p);
+
+	UpdateScrollLayout();
 }
 
 void
