@@ -6,6 +6,8 @@
 #include "Styles.hxx"
 #include "Options.hxx"
 #include "i18n.h"
+#include "lib/fmt/ToSpan.hxx"
+#include "ui/Options.hxx"
 #include "util/LocaleString.hxx"
 
 #include "config.h"
@@ -14,16 +16,16 @@
 
 #include <string.h>
 
+using std::string_view_literals::operator""sv;
+
 TitleBar::TitleBar(Point p, unsigned width) noexcept
 	:window(p, {width, GetHeight()})
 {
 	leaveok(window.w, true);
 	keypad(window.w, true);
 
-#ifdef ENABLE_COLORS
-	if (options.enable_colors)
+	if (ui_options.enable_colors)
 		window.SetBackgroundStyle(Style::TITLE);
-#endif
 }
 
 static inline int
@@ -59,51 +61,49 @@ TitleBar::Update(const struct mpd_status *status) noexcept
 
 void
 TitleBar::Paint(const PageMeta &current_page_meta,
-		const char *title) const noexcept
+		std::string_view title) const noexcept
 {
-	WINDOW *w = window.w;
-
-	wmove(w, 0, 0);
-	wclrtoeol(w);
+	window.MoveCursor({0, 0});
+	window.ClearToEol();
 
 #ifndef NCMPC_MINI
 	if (options.welcome_screen_list) {
-		PaintTabBar(w, current_page_meta, title);
+		PaintTabBar(window, current_page_meta, title);
 	} else {
 #else
 		(void)current_page_meta;
 #endif
-		SelectStyle(w, Style::TITLE_BOLD);
-		mvwaddstr(w, 0, 0, title);
+		SelectStyle(window, Style::TITLE_BOLD);
+		window.String({0, 0}, title);
 #ifndef NCMPC_MINI
 	}
 #endif
 
 	char buf[32];
-	const char *volume_string;
-	if (volume < 0)
-		volume_string = _("Volume n/a");
-	else {
-		snprintf(buf, sizeof(buf), _("Volume %d%%"), volume);
-		volume_string = buf;
+	std::string_view volume_string;
+	if (volume < 0) {
+		volume_string = FmtTruncate(buf, " {} {}"sv, _("Volume"), _("n/a"));
+	} else {
+		volume_string = FmtTruncate(buf, " {} {}"sv, _("Volume"), volume);
 	}
 
-	SelectStyle(w, Style::TITLE);
-	mvwaddstr(w, 0, window.size.width - StringWidthMB(volume_string),
-		  volume_string);
+	SelectStyle(window, Style::TITLE);
+	const int window_width = window.GetWidth();
+	window.String({window_width - (int)StringWidthMB(volume_string), 0},
+		      volume_string);
 
-	SelectStyle(w, Style::LINE);
-	mvwhline(w, 1, 0, ACS_HLINE, window.size.width);
+	SelectStyle(window, Style::LINE);
+	window.HLine({0, 1}, window_width, ACS_HLINE);
 	if (flags[0]) {
-		wmove(w, 1, window.size.width - strlen(flags) - 3);
-		waddch(w, '[');
-		SelectStyle(w, Style::LINE_FLAGS);
-		waddstr(w, flags);
-		SelectStyle(w, Style::LINE);
-		waddch(w, ']');
+		window.MoveCursor({window_width - (int)strlen(flags) - 3, 1});
+		window.Char('[');
+		SelectStyle(window, Style::LINE_FLAGS);
+		window.String(flags);
+		SelectStyle(window, Style::LINE);
+		window.Char(']');
 	}
 
-	wnoutrefresh(w);
+	window.RefreshNoOut();
 }
 
 void
