@@ -28,28 +28,32 @@ charset_init() noexcept
 #endif
 
 static char *
-CopyTruncateString(char *dest, size_t dest_size,
-		   const char *src, size_t src_length) noexcept
+CopyTruncateString(std::span<char> dest, const std::string_view src) noexcept
 {
-	dest = std::copy_n(src, std::min(dest_size - 1, src_length), dest);
-	*dest = 0;
-	return dest;
+	char *p = std::copy_n(src.begin(), std::min(dest.size() - 1, src.size()), dest.data());
+	*p = 0;
+	return p;
 }
 
 #ifdef HAVE_ICONV
 
 static char *
 Iconv(iconv_t i,
-      char *dest, size_t dest_size,
-      const char *src, size_t src_length) noexcept
+      std::span<char> _dest,
+      const std::string_view _src) noexcept
 {
 	static constexpr char FALLBACK = '?';
 
+	char *dest = _dest.data();
+	std::size_t dest_size = _dest.size();
 	--dest_size; /* reserve once byte for the null terminator */
 
+	char *src = const_cast<char *>(_src.data());
+	std::size_t src_length = _src.size();
+
 	while (src_length > 0) {
 		size_t err = iconv(i,
-				   const_cast<char **>(&src), &src_length,
+				   &src, &src_length,
 				   &dest, &dest_size);
 		if (err == (size_t)-1) {
 			switch (errno) {
@@ -87,35 +91,37 @@ Iconv(iconv_t i,
 
 static char *
 Iconv(const char *tocode, const char *fromcode,
-      char *dest, size_t dest_size,
-      const char *src, size_t src_length) noexcept
+      std::span<char> dest,
+      const std::string_view src) noexcept
 {
 	const auto i = iconv_open(tocode, fromcode);
 	if (i == (iconv_t)-1) {
-		CopyTruncateString(dest, dest_size, src, src_length);
-		return dest;
+		CopyTruncateString(dest, src);
+		return dest.data();
 	}
 
 	AtScopeExit(i) { iconv_close(i); };
 
-	return Iconv(i, dest, dest_size, src, src_length);
+	return Iconv(i, dest, src);
 }
 
 [[gnu::pure]]
 static std::string
-Iconv(iconv_t i,
-      const char *src, size_t src_length) noexcept
+Iconv(iconv_t i, const std::string_view _src) noexcept
 {
 	static constexpr char FALLBACK = '?';
 
 	std::string dest;
 
+	char *src = const_cast<char *>(_src.data());
+	std::size_t src_length = _src.size();
+
 	while (src_length > 0) {
 		char buffer[1024], *outbuf = buffer;
 		size_t outbytesleft = sizeof(buffer);
 
 		size_t err = iconv(i,
-				   const_cast<char **>(&src), &src_length,
+				   &src, &src_length,
 				   &outbuf, &outbytesleft);
 		dest.append(buffer, outbuf);
 		if (err == (size_t)-1) {
@@ -151,63 +157,51 @@ Iconv(iconv_t i,
 [[gnu::pure]]
 static std::string
 Iconv(const char *tocode, const char *fromcode,
-      const char *src, size_t src_length) noexcept
+      const std::string_view src) noexcept
 {
 	const auto i = iconv_open(tocode, fromcode);
 	if (i == (iconv_t)-1)
-		return {src, src_length};
+		return std::string{src};
 
 	AtScopeExit(i) { iconv_close(i); };
 
-	return Iconv(i, src, src_length);
+	return Iconv(i, src);
 }
 
 [[gnu::pure]]
 static std::string
-utf8_to_locale(const char *src, size_t length) noexcept
+utf8_to_locale(const std::string_view src) noexcept
 {
-	assert(src != nullptr);
-
 	if (noconvert)
-		return {src, length};
+		return std::string{src};
 
-	return Iconv(charset, "utf-8",
-		     src, length);
+	return Iconv(charset, "utf-8", src);
 }
 
 #endif
 
 char *
-CopyUtf8ToLocale(char *dest, size_t dest_size, const char *src) noexcept
-{
-	return CopyUtf8ToLocale(dest, dest_size, src, strlen(src));
-}
-
-char *
-CopyUtf8ToLocale(char *dest, size_t dest_size,
-		 const char *src, size_t src_length) noexcept
+CopyUtf8ToLocale(std::span<char> dest, const std::string_view src) noexcept
 {
 #ifdef HAVE_ICONV
 	if (noconvert) {
 #endif
-		return CopyTruncateString(dest, dest_size, src, src_length);
+		return CopyTruncateString(dest, src);
 #ifdef HAVE_ICONV
 	} else {
-		return Iconv(charset, "utf-8", dest, dest_size,
-			     src, src_length);
+		return Iconv(charset, "utf-8", dest, src);
 	}
 #endif
 }
 
-const char *
-utf8_to_locale(const char *src, char *buffer, size_t size) noexcept
+std::string_view
+utf8_to_locale(std::string_view src, std::span<char> buffer) noexcept
 {
 #ifdef HAVE_ICONV
-	CopyUtf8ToLocale(buffer, size, src);
-	return buffer;
+	char *end = CopyUtf8ToLocale(buffer, src);
+	return {buffer.data(), end};
 #else
 	(void)buffer;
-	(void)size;
 	return src;
 #endif
 }
@@ -216,24 +210,18 @@ utf8_to_locale(const char *src, char *buffer, size_t size) noexcept
 
 [[gnu::pure]]
 static std::string
-locale_to_utf8(const char *src) noexcept
+locale_to_utf8(const std::string_view src) noexcept
 {
-	assert(src != nullptr);
-
 	if (noconvert)
-		return src;
+		return std::string{src};
 
-	return Iconv("utf-8", charset,
-		     src, strlen(src));
+	return Iconv("utf-8", charset, src);
 }
 
-Utf8ToLocale::Utf8ToLocale(const char *src) noexcept
-	:Utf8ToLocale(src, strlen(src)) {}
+Utf8ToLocale::Utf8ToLocale(const std::string_view src) noexcept
+	:value(utf8_to_locale(src)) {}
 
-Utf8ToLocale::Utf8ToLocale(const char *src, size_t length) noexcept
-	:value(utf8_to_locale(src, length)) {}
-
-LocaleToUtf8::LocaleToUtf8(const char *src) noexcept
+LocaleToUtf8::LocaleToUtf8(const std::string_view src) noexcept
 	:value(locale_to_utf8(src)) {}
 
 #endif
