@@ -11,19 +11,15 @@ hscroll::OnTimer() noexcept
 {
 	Step();
 	Paint();
-	wrefresh(w);
+	window.Refresh();
 	ScheduleTimer();
 }
 
 void
-hscroll::Set(unsigned _x, unsigned _y, unsigned _width, const char *_text,
+hscroll::Set(Point _position, unsigned _width, std::string_view _text,
 	     Style _style, attr_t _attr) noexcept
 {
-	assert(w != nullptr);
-	assert(_text != nullptr);
-
-	x = _x;
-	y = _y;
+	position = _position;
 	style = _style;
 	attr = _attr;
 
@@ -43,18 +39,17 @@ hscroll::Clear() noexcept
 void
 hscroll::Paint() const noexcept
 {
-	assert(w != nullptr);
 	assert(basic.IsDefined());
 
-	SelectStyle(w, style);
+	SelectStyle(window, style);
 
 	if (attr != 0)
-		wattron(w, attr);
+		window.AttributeOn(attr);
 
 	/* scroll the string, and draw it */
 	const auto s = basic.ScrollString();
-	mvwaddnstr(w, y, x, s.first, s.second);
+	window.String(position, s);
 
 	if (attr != 0)
-		wattroff(w, attr);
+		window.AttributeOff(attr);
 }
