@@ -1,8 +1,7 @@
 // SPDX-License-Identifier: GPL-2.0-or-later
 // Copyright The Music Player Daemon Project
 
-#ifndef I18N_H
-#define I18N_H
+#pragma once
 
 #include "config.h"
 
@@ -10,6 +9,7 @@
 
 #include <libintl.h> // IWYU pragma: export
 
+#define my_gettext(x) gettext(x)
 #define _(x) gettext(x)
 
 #ifdef gettext_noop
@@ -19,12 +19,10 @@
 #endif
 
 #else
-#define gettext(x) (x)
+#define my_gettext(x) (x)
 #define  _(x) x
 #define N_(x) x
 #endif
 
 #define YES_TRANSLATION _("y")
 #define NO_TRANSLATION _("n")
-
-#endif
