@@ -2,7 +2,7 @@
 // Copyright The Music Player Daemon Project
 
 #include "lirc.hxx"
-#include "ncmpc.hxx"
+#include "UserInputHandler.hxx"
 #include "Command.hxx"
 #include "config.h"
 
@@ -13,21 +13,18 @@ LircInput::OnSocketReady(unsigned) noexcept
 {
 	char *code, *txt;
 
-	begin_input_event();
-
 	if (lirc_nextcode(&code) == 0) {
 		while (lirc_code2char(lc, code, &txt) == 0 && txt != nullptr) {
 			const auto cmd = get_key_command_from_name(txt);
-			if (!do_input_event(GetEventLoop(), cmd))
-				return;
+			handler.OnCommand(cmd);
 		}
 	}
-
-	end_input_event();
 }
 
-LircInput::LircInput(EventLoop &_event_loop) noexcept
-	:event(_event_loop, BIND_THIS_METHOD(OnSocketReady))
+LircInput::LircInput(EventLoop &_event_loop,
+		     UserInputHandler &_handler) noexcept
+	:handler(_handler),
+	 event(_event_loop, BIND_THIS_METHOD(OnSocketReady))
 {
 	int lirc_socket = 0;
 
