@@ -4,7 +4,7 @@
 #include "Page.hxx"
 #include "Container.hxx"
 #include "ui/Window.hxx"
-#include "screen_status.hxx"
+#include "util/Exception.hxx"
 
 void
 Page::OnClose() noexcept
@@ -19,6 +19,12 @@ Page::SchedulePaint() noexcept
 	parent.SchedulePaint(*this);
 }
 
+Interface &
+Page::GetInterface() const noexcept
+{
+	return parent;
+}
+
 void
 Page::Alert(std::string message) noexcept
 {
@@ -54,7 +60,7 @@ inline void
 Page::_OnCoComplete(std::exception_ptr error) noexcept
 {
 	if (error)
-		screen_status_error(std::move(error));
+		parent.Alert(GetFullMessage(std::move(error)));
 	else
 		OnCoComplete();
 }
