@@ -3,7 +3,6 @@
 
 #include "save_playlist.hxx"
 #include "db_completion.hxx"
-#include "screen_status.hxx"
 #include "config.h" // IWYU pragma: keep
 #include "i18n.h"
 #include "charset.hxx"
@@ -17,6 +16,8 @@
 
 #include <mpd/client.h>
 
+#include <fmt/core.h>
+
 #include <stdio.h>
 
 #ifndef NCMPC_MINI
@@ -73,8 +74,7 @@ playlist_save(ScreenManager &screen, struct mpdclient &c,
 		filename = co_await TextInputDialog{
 			screen, _("Save queue as"),
 			{},
-			nullptr,
-			completion,
+			{ .completion = completion },
 		};
 
 		if (filename.empty())
