@@ -4,7 +4,6 @@
 #include "screen.hxx"
 #include "PageMeta.hxx"
 #include "screen_list.hxx"
-#include "screen_status.hxx"
 #include "Command.hxx"
 #include "config.h"
 #include "i18n.h"
@@ -21,6 +20,7 @@
 #include "ui/Options.hxx"
 #include "co/Task.hxx"
 #include "client/mpdclient.hxx"
+#include "util/Exception.hxx"
 #include "util/ScopeExit.hxx"
 #include "util/StringAPI.hxx"
 
@@ -227,7 +227,7 @@ ScreenManager::OnCommand(struct mpdclient &c, DelayedSeek &seek, Command cmd)
 	if (GetCurrentPage().OnCommand(c, cmd))
 		return;
 
-	if (handle_player_command(c, seek, cmd))
+	if (handle_player_command(*this, c, seek, cmd))
 		return;
 
 	switch(cmd) {
@@ -400,7 +400,7 @@ EnterPassword(ScreenManager &screen, struct mpdclient &c)
 
 	co_return co_await TextInputDialog{
 		screen, _("Password"), {},
-		nullptr, nullptr, true,
+		{ .masked = true },
 	};
 }
 
@@ -453,7 +453,7 @@ inline void
 ScreenManager::OnCoComplete(std::exception_ptr error) noexcept
 {
 	if (error)
-		screen_status_error(std::move(error));
+		Alert(GetFullMessage(std::move(error)));
 }
 
 void
