@@ -3,13 +3,14 @@
 
 #include "EventFD.hxx"
 #include "system/Error.hxx"
+#include "util/SpanCast.hxx"
 
 #include <cassert>
 
 #include <sys/eventfd.h>
 
 EventFD::EventFD()
-	:fd(::eventfd(0, EFD_NONBLOCK|EFD_CLOEXEC))
+	:fd(AdoptTag{}, ::eventfd(0, EFD_NONBLOCK|EFD_CLOEXEC))
 {
 	if (!fd.IsDefined())
 		throw MakeErrno("eventfd() failed");
@@ -21,7 +22,7 @@ EventFD::Read() noexcept
 	assert(fd.IsDefined());
 
 	eventfd_t value;
-	return fd.Read(&value, sizeof(value)) == (ssize_t)sizeof(value);
+	return fd.Read(std::as_writable_bytes(std::span{&value, 1})) == (ssize_t)sizeof(value);
 }
 
 void
@@ -31,5 +32,5 @@ EventFD::Write() noexcept
 
 	static constexpr eventfd_t value = 1;
 	[[maybe_unused]] ssize_t nbytes =
-		fd.Write(&value, sizeof(value));
+		fd.Write(ReferenceAsBytes(value));
 }
